@@ -1763,6 +1763,12 @@ class InformacionAlConsumidor(object):
             return self.informacion_al_consumidor.FechaInicioAnioMovil.text.strip()
         return None
 
+    @property
+    def valor_energia_media_cp(self):
+        if hasattr(self.informacion_al_consumidor, 'ValorEnergiaMediaCP'):
+            return float(self.informacion_al_consumidor.ValorEnergiaMediaCP.text.strip())
+        return None
+
     @property
     def periodos(self):
         data = []
